@@ -1511,7 +1511,7 @@ class ContentNode(object):
         """
         return self.previous_node(node_type_re=node_type_re, skip_virtual=skip_virtual) is not None
 
-    def next_node(self, node_type_re='.*', skip_virtual=False, has_no_content=True):
+    def next_node(self, node_type_re='.*', skip_virtual=False, has_no_content=True, traverse=Traverse.SIBLING):
         """Returns the next sibling content node.
 
         Note:  This logic relies on node indexes.  Documents allow for sparse representation and child nodes may not have consecutive index numbers.
@@ -1534,6 +1534,11 @@ class ContentNode(object):
             node = self.get_parent().get_node_at_index(search_index) if self.get_parent() else None
 
             if not node:
+                if (traverse == traverse.ALL or traverse == traverse.PARENT) and self.get_parent().get_parent():
+                    # can now traverse content-areas.. can add traversal of pages if needed, but don't think the scenario exists.
+                    potential_next_node = self.get_parent().get_parent().get_children()[self.get_parent().index + 1].get_children()[0]
+                    if potential_next_node:
+                        return potential_next_node
                 return node
 
             if compiled_node_type_re.match(node.node_type) and (not skip_virtual or not node.virtual):
@@ -2011,10 +2016,7 @@ class Document(object):
                 'content_node': self.content_node.to_dict() if self.content_node else None,
                 'source': clean_none_values(dataclasses.asdict(self.source)),
                 'mixins': self._mixins,
-                'taxonomies': self.taxonomies,
                 'classes': [content_class.to_dict() for content_class in self.classes],
-                'exceptions': self.exceptions,
-                'log': self.log,
                 'labels': self.labels,
                 'uuid': self.uuid}
 
@@ -2034,8 +2036,6 @@ class Document(object):
         new_document = Document(DocumentMetadata(doc_dict['metadata']))
         new_document.version = doc_dict['version'] if 'version' in doc_dict and doc_dict[
             'version'] else Document.PREVIOUS_VERSION  # some older docs don't have a version or it's None
-        new_document.log = doc_dict['log'] if 'log' in doc_dict else []
-        new_document.exceptions = doc_dict['exceptions'] if 'exceptions' in doc_dict else []
         new_document.uuid = doc_dict['uuid'] if 'uuid' in doc_dict else str(
             uuid.uuid5(uuid.NAMESPACE_DNS, 'kodexa.com'))
 
@@ -2046,11 +2046,6 @@ class Document(object):
             new_document.source = SourceMetadata.from_dict(doc_dict['source'])
         if 'labels' in doc_dict and doc_dict['labels']:
             new_document.labels = doc_dict['labels']
-        if 'taxomomies' in doc_dict and doc_dict['taxomomies']:
-            new_document.labels = doc_dict['taxomomies']
-        if 'classes' in doc_dict and doc_dict['classes']:
-            new_document.classes = [ContentClassification.from_dict(content_class) for content_class in
-                                    doc_dict['classes']]
 
         new_document.get_persistence().update_metadata()
         return new_document
